==> haskell-attoparsec-iso8601-1.0.0.0-12-i686.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec-iso8601
version: 1.0.0.0
id: attoparsec-iso8601-1.0.0.0-Ki0HYX5fjEpFYBTTXMcaAt
key: attoparsec-iso8601-1.0.0.0-Ki0HYX5fjEpFYBTTXMcaAt
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Parsing of ISO 8601 dates, originally from aeson.
description:
    Parsing of ISO 8601 dates, originally from aeson.
category: Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Attoparsec.Time Data.Attoparsec.Time.Internal
abi: 98a3584e2c5f1f061fee3fc5f964c1ba
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/attoparsec-iso8601-1.0.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/attoparsec-iso8601-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/attoparsec-iso8601-1.0.0.0
hs-libraries: HSattoparsec-iso8601-1.0.0.0-Ki0HYX5fjEpFYBTTXMcaAt
depends:
    attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j base-4.10.0.0
    base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
abi-depends: attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j=408c5a9ef40ae69c083ed9d4aba83592
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
haddock-interfaces: /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock
haddock-html: /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-iso8601-1.0.0.0-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec-iso8601
version: 1.0.0.0
id: attoparsec-iso8601-1.0.0.0-1p5IOTQVJmz4aJFp1Mq3SO
key: attoparsec-iso8601-1.0.0.0-1p5IOTQVJmz4aJFp1Mq3SO
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Parsing of ISO 8601 dates, originally from aeson.
description:
    Parsing of ISO 8601 dates, originally from aeson.
category: Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Attoparsec.Time Data.Attoparsec.Time.Internal
abi: eee821cad24214928cbe946ac681bbf8
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/attoparsec-iso8601-1.0.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/attoparsec-iso8601-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/attoparsec-iso8601-1.0.0.0
hs-libraries: HSattoparsec-iso8601-1.0.0.0-1p5IOTQVJmz4aJFp1Mq3SO
depends:
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm base-4.10.0.0
    base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
abi-depends: attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
haddock-interfaces: /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock
haddock-html: /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
